require 'startupgem/game' 

module Startupgem 
	RSpec.describe Game do 
		before do
			$stdout = StringIO.new
		end

		context 'can roll the dice to w00t, blam and skip the player.' do
			before do
				@initial_health = 100
				@player = Player.new('ironman',@initial_health)
				@game = Game.new('show me the money')
				@game.add_player(@player)
			end

			it 'rolled high number and w00ted (+ 15 health each round) the player' do
				allow_any_instance_of(Dice).to receive(:roll).and_return(5)
				@game.play(2)

				expect(@player.health).to eq(@initial_health + (15 * 2))
			end

			it 'rolled medium number skipped the player' do
				allow_any_instance_of(Dice).to receive(:roll).and_return(4)
				@game.play(2)

				expect(@player.health).to eq(@initial_health)
			end


			it 'rolled low number and blammed (-10 health each round) the player' do
			 	allow_any_instance_of(Dice).to receive(:roll).and_return(1)

			 	@game.play(2)

			 	expect(@player.health).to eq(@initial_health - (10 * 2))
			end
		end

		context 'In an array of players,' do
			before do
				@player1 = Player.new('spiderman',100)
				@player2 = Player.new('superman',200)
				@player3 = Player.new('batman',250)

				@players = [@player3, @player2, @player1]	
			end
			
			it "it is sorted in descending order by player's score" do
				expect(@players.sort).to eq(@players)
			end
		end

		context "lets each player find random treasures." do
			before do
				@player1 = Player.new(:ironman,100)
				@player2 = Player.new(:batman,70)
				@game = Game.new('show me the money')
			end


			it 'On each turn, a player finds a treasure and stores its points' do
				@game.add_player(@player1)
				@game.play(1)

				expect(@player1.points).not_to eql(0)
			end

			it 'computes total treasure points as sum of all player points' do

				@player1.found_treasure(Treasure.new(:autumn,100))
				@player1.found_treasure(Treasure.new(:sushi,100))
				@player2.found_treasure(Treasure.new(:coffee,90))
				@game.add_player(@player1)
				@game.add_player(@player2)

				expect(@game.total_treasure_points).to eq(100 + 100 + 90)

			end
		end
	end
end
