
require 'startupgem/player'
require 'startupgem/helper'
require 'startupgem/treasure_trove'
require 'startupgem/game'

module Startupgem
	RSpec.describe Player do
		before do
			$stdout = StringIO.new
		end

		context "class has methods." do
			before do
				@initial_health = 200
				@name = 'mason'
				@player = Player.new(@name,@initial_health)
				@game = Game.new('show me the money')
			end

			it "has a capitalized name" do
				# expect(@player.name).to eq("Mason")
				@player.name.should == "Mason"
			end

			it "has an initial health" do 
				expect(@player.health).to eq(@initial_health)
			end

			it "has a string representation" do
				@player.found_treasure(Treasure.new(:autumn,100))
				expect(@player.to_s).to eq("\tI'm Mason with a health = 200, points = 100, score = 300.")
			end

			it "computes a score as the sum of its health and points" do
				@player.found_treasure(Treasure.new(:autumn,100))
				@player.found_treasure(Treasure.new(:focusfactor,95))
				expect(@player.score).to eq(@initial_health + @player.points)
			end

			it "increases health by 15 when w00ted" do
				@player.w00t
				expect(@player.health).to eq(@initial_health + 15)
			end

			it "decreases health by 10 when blammed" do
				@player.blam
				expect(@player.health).to eq(@initial_health - 10)
			end

			it 'Accumulates and stores each given treasure and points' do
				allow(TreasureTrove).to receive(:random).and_return(Treasure.new(:Autumn,200))
				expect(@player.points).to eq(0)
				@game.add_player(@player)
				@game.play(1)
				expect(@player.points).to eq(200)

				@player.found_treasure(Treasure.new(:monitor,70))
				expect(@player.points).to eq(200 + 70)

				@player.found_treasure(Treasure.new(:applemouse,50))
				expect(@player.points).to eq(270 + 50)
			end	

			it 'yields each treasure found and its total points' do

				Treasures = [Treasure.new(:sushi,90), Treasure.new(:autumn,100), Treasure.new(:coffee,70)]

				@player.found_treasure(Treasures[0])
				@player.found_treasure(Treasures[1])
				@player.found_treasure(Treasures[2])


				yielded = Array.new

				@player.print_each_treasure do |treasure|
					yielded.push(treasure)
				end

				expect(yielded).to match_array(Treasures)
			end

			it 'Takes each line of strings given from csv file and converts it into a Player object' do
				csv = "ruby,10"
				player = Player.convert(csv)
				expect(player.name).to eq("Ruby")
				expect(player.health).to eq(10)
			end
		end

		context "with a health above 150" do
			before do
				@initial_health = 150
				@player = Player.new('ironman',@initial_health)
			end

			it "returns true for strong if health is greater than 150" do
				expect(@player).to be_strong
			end
		end

		context 'with a health of 100 or less' do 
			before do
				@initial_health = 90
				@player = Player.new('captain america',@initial_health)
			end

			it 'is wimpy' do
				expect(@player).to_not be_strong
			end
		end
	end
end


